@@ -60,6 +60,7 @@ const TestInfo tests[] = {
 	{ "algebra/filter-in-2", "algebra/data-2", FALSE },
 	{ "algebra/filter-in-3", "algebra/data-2", FALSE },
 	{ "algebra/filter-in-4", "algebra/data-2", FALSE },
+	{ "algebra/filter-in-5", "algebra/data-2", FALSE },
 	{ "algebra/var-scope-join-1", "algebra/var-scope-join-1", FALSE },
 	{ "anon/query", "anon/data", FALSE },
 	{ "ask/ask-1", "ask/data", FALSE },
@@ -92,6 +93,9 @@ const TestInfo tests[] = {
 	{ "functions/functions-xpath-4", "functions/data-1", FALSE },
 	{ "functions/functions-xpath-5", "functions/data-1", FALSE },
 	{ "functions/functions-xpath-6", "functions/data-1", FALSE },
+	{ "functions/functions-xpath-7", "functions/data-1", FALSE },
+	{ "functions/functions-xpath-8", "functions/data-1", FALSE },
+	{ "functions/functions-xpath-9", "functions/data-1", FALSE },
 	{ "graph/graph-1", "graph/data-1", FALSE },
 	{ "graph/graph-2", "graph/data-2", FALSE },
 	{ "graph/graph-3", "graph/data-3", FALSE },
@@ -235,7 +239,9 @@ test_sparql_query (gconstpointer test_data)
 
 	tracker_data_manager_init (TRACKER_DB_MANAGER_FORCE_REINDEX,
 	                           test_schemas,
-	                           NULL, FALSE, 100, 100, NULL, NULL, NULL);
+	                           NULL, FALSE, 100, 100, NULL, NULL, NULL, &error);
+
+	g_assert_no_error (error);
 
 	/* data_path = g_build_path (G_DIR_SEPARATOR_S, TOP_SRCDIR, "tests", "libtracker-data", NULL); */
 
